==> ev_framework-0.0.4.tar.gz: lib/Elves/Chatroom/Ev_Chatroom.dart <==
import 'dart:io';
import '../API/Ev_API.dart';
import 'package:flutter/material.dart';
import '_Ev_Chat_Input.dart';
import '_Ev_Chat_View.dart';

class Ev_Chatroom extends StatelessWidget {
  String chat_url;
  String Send_message_url;
  bool hasfile = false;

  var post;
  var Self_message_bgcolor;
  var Other_message_bgcolor;
  var Self_message_fontcolor;
  var Other_message_fontcolor;


  GlobalKey<$Ev_Chat_ViewtState> chatview = GlobalKey();

  var input_image_icon;
  var input_send_icon;
  var input_bgcolor;

  var api = Ev_API();

  Ev_Chatroom(
      {this.chat_url, this.Send_message_url, this.post,
        this.Self_message_bgcolor = Colors.greenAccent,
        this.Other_message_bgcolor = Colors.white,
        this.Self_message_fontcolor = Colors.black,
        this.Other_message_fontcolor = Colors.black,
        this.hasfile,
        this.input_image_icon, this.input_send_icon, this.input_bgcolor
      });

  @override
  Widget build(BuildContext context) {
    return Container(width: double.infinity, height: double.infinity,
        child: Column(
          children: <Widget>[
            Expanded(child: $Ev_Chat_View(url: chat_url,
                post: post,
                Send_message_url: Send_message_url,
                self_fontcolor:Self_message_fontcolor,
                Self_bgcolor: Self_message_bgcolor,
                other_fontcolor: Other_message_fontcolor,
                Other_bgcolor: Other_message_bgcolor,
                key: chatview)),
            Divider(height: 1, color: Colors.black26,),
            Chat_Input(get_image_icon: input_image_icon,
              send_icon: input_send_icon,
              bgcolor: input_bgcolor,
              hasfile: hasfile,
              onMessage: Get_Message,
              onFile: Get_File,
              onPhoto: Get_Photo,
              onChange: On_Change,
            )
          ],
        ));
  }

  void Get_Message(String message)
  {  chatview.currentState.Send_Message(message); }

  void Get_Photo(File file)
  {  print("Get Photo:" + file.toString());
     chatview.currentState.Send_Photo(file); }


  void Get_File(File file)
  {  print("Get File:" + file.toString());
     chatview.currentState.Send_File(file); }

  void On_Change(String message)
  {   }

}

==> ev_framework-2.0.4.tar.gz: lib/Elves/Chatroom/Ev_Chatroom.dart <==
import 'dart:io';
import '../API/Ev_API.dart';
import 'package:flutter/material.dart';
import '_Ev_Chat_Input.dart';
import '_Ev_Chat_View.dart';

class Ev_Chatroom extends StatelessWidget {
  String chat_url;
  String Send_message_url;
  bool hasfile = false;

  var post;
  var Self_message_bgcolor;
  var Other_message_bgcolor;
  var Self_message_fontcolor;
  var Other_message_fontcolor;


  GlobalKey<$Ev_Chat_ViewtState> chatview = GlobalKey();

  var input_image_icon;
  var input_send_icon;
  var input_bgcolor;
  int refresh_time = 0;

  var api = Ev_API();

  Ev_Chatroom(
      {this.chat_url, this.Send_message_url, this.post,
        this.Self_message_bgcolor = Colors.greenAccent,
        this.Other_message_bgcolor = Colors.white,
        this.Self_message_fontcolor = Colors.black,
        this.Other_message_fontcolor = Colors.black,
        this.hasfile,
        this.input_image_icon, this.input_send_icon, this.input_bgcolor,
        this.refresh_time = 0
      });

  @override
  Widget build(BuildContext context) {
    return Container(width: double.infinity, height: double.infinity,
        child: Column(
          children: <Widget>[
            Expanded(child: $Ev_Chat_View(url: chat_url,
                post: post,
                Send_message_url: Send_message_url,
                self_fontcolor:Self_message_fontcolor,
                Self_bgcolor: Self_message_bgcolor,
                other_fontcolor: Other_message_fontcolor,
                Other_bgcolor: Other_message_bgcolor,
                refresh_time: refresh_time,
                key: chatview)),
            Divider(height: 1, color: Colors.black26,),
            Chat_Input(get_image_icon: input_image_icon,
              send_icon: input_send_icon,
              bgcolor: input_bgcolor,
              hasfile: hasfile,
              onMessage: Get_Message,
              onFile: Get_File,
              onPhoto: Get_Photo,
              onChange: On_Change,
            )
          ],
        ));
  }

  void Get_Message(String message)
  {  chatview.currentState.Send_Message(message); }

  void Get_Photo(File file)
  {  print("Get Photo:" + file.toString());
     chatview.currentState.Send_Photo(file); }


  void Get_File(File file)
  {  print("Get File:" + file.toString());
     chatview.currentState.Send_File(file); }

  void On_Change(String message)
  {   }

}
